aboutsummaryrefslogtreecommitdiff
path: root/gdb
diff options
context:
space:
mode:
authorMichael Snyder <msnyder@vmware.com>2000-11-08 23:58:46 +0000
committerMichael Snyder <msnyder@vmware.com>2000-11-08 23:58:46 +0000
commitf44c642f36a04395d9ed51829f0c44c68dd27a6b (patch)
tree3df3e4cf30a0601c55d89c4ca5b178e87ea01c28 /gdb
parent8546af7422f2fafb1fd7c9ff666cc043be0efde2 (diff)
downloadgdb-f44c642f36a04395d9ed51829f0c44c68dd27a6b.zip
gdb-f44c642f36a04395d9ed51829f0c44c68dd27a6b.tar.gz
gdb-f44c642f36a04395d9ed51829f0c44c68dd27a6b.tar.bz2
2000-11-08 Michael Snyder <msnyder@cleaver.cygnus.com>
* gdbarch.sh: Spelling correction: registrary -> registry. * gdbarch.c: Ditto.
Diffstat (limited to 'gdb')
-rw-r--r--gdb/ChangeLog5
-rwxr-xr-xgdb/gdbarch.sh34
2 files changed, 22 insertions, 17 deletions
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index bf28a84..dc8f14f 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,8 @@
+2000-11-08 Michael Snyder <msnyder@cleaver.cygnus.com>
+
+ * gdbarch.sh: Spelling correction: registrary -> registry.
+ * gdbarch.c: Ditto.
+
Wed Nov 8 23:08:48 2000 Andrew Cagney <cagney@b1.cygnus.com>
* m68k-tdep.c (m68k_get_longjmp_target): Work around targets that
diff --git a/gdb/gdbarch.sh b/gdb/gdbarch.sh
index 541250f..8dfe5f8 100755
--- a/gdb/gdbarch.sh
+++ b/gdb/gdbarch.sh
@@ -1470,7 +1470,7 @@ done
cat <<EOF
/* Keep a registrary of per-architecture data-pointers required by GDB
modules. */
struct gdbarch_data
@@ -1485,13 +1485,13 @@ struct gdbarch_data_registration
struct gdbarch_data_registration *next;
};
-struct gdbarch_data_registrary
+struct gdbarch_data_registry
{
int nr;
struct gdbarch_data_registration *registrations;
};
-struct gdbarch_data_registrary gdbarch_data_registrary =
+struct gdbarch_data_registry gdbarch_data_registry =
{
0, NULL,
};
@@ -1500,14 +1500,14 @@ struct gdbarch_data *
register_gdbarch_data (gdbarch_data_ftype *init)
{
struct gdbarch_data_registration **curr;
- for (curr = &gdbarch_data_registrary.registrations;
+ for (curr = &gdbarch_data_registry.registrations;
(*curr) != NULL;
curr = &(*curr)->next);
(*curr) = XMALLOC (struct gdbarch_data_registration);
(*curr)->next = NULL;
(*curr)->init = init;
(*curr)->data = XMALLOC (struct gdbarch_data);
- (*curr)->data->index = gdbarch_data_registrary.nr++;
+ (*curr)->data->index = gdbarch_data_registry.nr++;
return (*curr)->data;
}
@@ -1518,9 +1518,9 @@ static void
init_gdbarch_data (struct gdbarch *gdbarch)
{
struct gdbarch_data_registration *rego;
- gdbarch->nr_data = gdbarch_data_registrary.nr + 1;
+ gdbarch->nr_data = gdbarch_data_registry.nr + 1;
gdbarch->data = xmalloc (sizeof (void*) * gdbarch->nr_data);
- for (rego = gdbarch_data_registrary.registrations;
+ for (rego = gdbarch_data_registry.registrations;
rego != NULL;
rego = rego->next)
{
@@ -1543,7 +1543,7 @@ gdbarch_data (struct gdbarch_data *data)
/* Keep a registrary of swapped data required by GDB modules. */
struct gdbarch_swap
{
@@ -1560,13 +1560,13 @@ struct gdbarch_swap_registration
struct gdbarch_swap_registration *next;
};
-struct gdbarch_swap_registrary
+struct gdbarch_swap_registry
{
int nr;
struct gdbarch_swap_registration *registrations;
};
-struct gdbarch_swap_registrary gdbarch_swap_registrary =
+struct gdbarch_swap_registry gdbarch_swap_registry =
{
0, NULL,
};
@@ -1577,7 +1577,7 @@ register_gdbarch_swap (void *data,
gdbarch_swap_ftype *init)
{
struct gdbarch_swap_registration **rego;
- for (rego = &gdbarch_swap_registrary.registrations;
+ for (rego = &gdbarch_swap_registry.registrations;
(*rego) != NULL;
rego = &(*rego)->next);
(*rego) = XMALLOC (struct gdbarch_swap_registration);
@@ -1593,7 +1593,7 @@ init_gdbarch_swap (struct gdbarch *gdbarch)
{
struct gdbarch_swap_registration *rego;
struct gdbarch_swap **curr = &gdbarch->swap;
- for (rego = gdbarch_swap_registrary.registrations;
+ for (rego = gdbarch_swap_registry.registrations;
rego != NULL;
rego = rego->next)
{
@@ -1632,7 +1632,7 @@ swapin_gdbarch_swap (struct gdbarch *gdbarch)
}
/* Keep a registrary of the architectures known by GDB. */
struct gdbarch_registration
{
@@ -1643,7 +1643,7 @@ struct gdbarch_registration
struct gdbarch_registration *next;
};
-static struct gdbarch_registration *gdbarch_registrary = NULL;
+static struct gdbarch_registration *gdbarch_registry = NULL;
static void
append_name (const char ***buf, int *nr, const char *name)
@@ -1664,7 +1664,7 @@ gdbarch_printable_names (void)
int nr_arches = 0;
const char **arches = NULL;
struct gdbarch_registration *rego;
- for (rego = gdbarch_registrary;
+ for (rego = gdbarch_registry;
rego != NULL;
rego = rego->next)
{
@@ -1703,7 +1703,7 @@ gdbarch_register (enum bfd_architecture bfd_architecture,
internal_error ("gdbarch: Attempt to register unknown architecture (%d)", bfd_architecture);
}
/* Check that we haven't seen this architecture before */
- for (curr = &gdbarch_registrary;
+ for (curr = &gdbarch_registry;
(*curr) != NULL;
curr = &(*curr)->next)
{
@@ -1800,7 +1800,7 @@ gdbarch_update_p (struct gdbarch_info info)
/* A default for abfd? */
/* Find the target that knows about this architecture. */
- for (rego = gdbarch_registrary;
+ for (rego = gdbarch_registry;
rego != NULL;
rego = rego->next)
if (rego->bfd_architecture == info.bfd_architecture)
@@ -1470,7 +1470,7 @@ done
cat <<EOF
-/* Keep a registrary of per-architecture data-pointers required by GDB
+/* Keep a registry of per-architecture data-pointers required by GDB
modules. */
struct gdbarch_data
@@ -1543,7 +1543,7 @@ gdbarch_data (struct gdbarch_data *data)
{
-/* Keep a registrary of swapped data required by GDB modules. */
+/* Keep a registry of swapped data required by GDB modules. */
struct gdbarch_swap
{
@@ -1632,7 +1632,7 @@ swapin_gdbarch_swap (struct gdbarch *gdbarch)
}
-/* Keep a registrary of the architectures known by GDB. */
+/* Keep a registry of the architectures known by GDB. */
struct gdbarch_registration
{